==> sccmilter-0.94.8.tar.bz2: sccmilter-0.94.8/libconf/strncasestr.c <==
/*-
 * Copyright (c) 1990, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * This code is derived from software contributed to Berkeley by
 * Chris Torek.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

// This is a slighlty modified version of standrd FreeBSD function strcasestr.
// Modification is only allowing set length of BIG string to make '\0' finish-char
// useless, like strnstr, strncmp, strncpy, etc...
// $Id: strncasestr.c,v 0.93 2003/08/26 12:56:55 shelton Exp $

// We do not insert our headers here. We do not need another glory. But, as usual:
// NO WARRANTY ANYWAY!!

#include "make.h"

/*
 * Find the first occurrence of find in s, ignore case, no more len characters
 */
char *strncasestr(register const char *s, register const char *find, size_t len)
{
  register char c, sc;
  register size_t flen,llen;

  if ((c = *find++) != 0)
    {

// Convert first char from line to lower case and compute rest searched line length

      c = tolower((unsigned char) c);
      flen = strlen(find);

// High level loop - until we don't find exact match between big and little lines

      do
       {

// Engine level loop - until we reach end-of-line or NULL-char

  	 for(llen = 1,sc = (*s++);(char) tolower((u_char) sc) != c;s++,llen++)
  	  if (((sc = *s) == 0) || (llen >= len))
  	    return (NULL);

// Decrease line length to already searched length

         len -= llen;
       } while (strncasecmp(s, find, flen) != 0);

// Point to first byte in line

      s--;
    }

  return ((char *)s);
}

==> sccmilter-0.95.1.tar.bz2: sccmilter-0.95.1/libconf/strncasestr.c <==
/*-
 * Copyright (c) 1990, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * This code is derived from software contributed to Berkeley by
 * Chris Torek.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

// This is a slighlty modified version of standrd FreeBSD function strcasestr.
// Modification is only allowing set length of BIG string to make '\0' finish-char
// useless, like strnstr, strncmp, strncpy, etc...
// $Id: strncasestr.c,v 0.93.10.1 2005/03/02 06:59:08 shelton Exp $

// We do not insert our headers here. We do not need another glory. But, as usual:
// NO WARRANTY ANYWAY!!

#include "make.h"

/*
 * Find the first occurrence of find in s, ignore case, no more len characters
 */
char *strncasestr(register const char *s, register const char *find, size_t len)
{
  register char c, sc;
  register size_t flen,llen;

  if ((c = *find++) != 0)
    {

// Convert first char from line to lower case and compute rest searched line length

      c = tolower((unsigned char) c);
      flen = strlen(find);

// High level loop - until we don't find exact match between big and little lines

      do
       {

// Engine level loop - until we reach end-of-line or NULL-char

  	 for(llen = 1,sc = (*s++);
  	 	(llen < len) && ((char) tolower((u_char) sc) != c);s++,llen++)
  	  if ((sc = *s) == 0)
  	    return (NULL);

// When we exhaust source line, but didn't find little, we return NULL

	 if (llen >= len)
           return NULL;

// Decrease line length to already searched length

         len -= llen;

       } while (strncasecmp(s, find, flen) != 0);

// Point to first byte in line

      s--;
    }

  return ((char *)s);
}
